==> pycoalprocessing_1.0.2.zip: pycoalprocessing_1.0.2/prototypes/item-groups.lua <==
--[[Item Groups and Subgroups]] --

data:extend {
    {
        type = "item-group",
        name = "coal-processing",
        order = "t",
        inventory_order = "t",
        icon = "__pycoalprocessing__/graphics/technology/item-group.png",
        icon_size = 64
    },
    {
        type = "item-subgroup",
        name = "coal-processing",
        group = "coal-processing",
        order = "a1"
    },
    {
        type = "item-subgroup",
        name = "py-power",
        group = "coal-processing",
        order = "a2"
    },
    {
        type = "item-subgroup",
        name = "py-fluid-handling",
        group = "coal-processing",
        order = "a3"
    },
    {
        type = "item-subgroup",
        name = "py-extraction",
        group = "coal-processing",
        order = "a4"
    },
    {
        type = "item-subgroup",
        name = "py-items",
        group = "coal-processing",
        order = "c"
    },
    {
        type = "item-subgroup",
        name = "py-items-hpf",
        group = "coal-processing",
        order = "c-1"
    },
    {
        type = "item-subgroup",
        name = "py-items-class",
        group = "coal-processing",
        order = "c-2"
    },
    {
        type = "item-subgroup",
        name = "py-washer",
        group = "coal-processing",
        order = "c-3"
    },
    {
        type = "item-subgroup",
        name = "py-quenching-ores",
        group = "coal-processing",
        order = "d"
    },
    {
        type = "item-subgroup",
        name = "py-syngas",
        group = "coal-processing",
        order = "e"
    },
    {
        type = "item-subgroup",
        name = "py-methanol",
        group = "coal-processing",
        order = "f"
    },
    {
        type = "item-subgroup",
        name = "py-crusher",
        group = "coal-processing",
        order = "g"
    },
    {
        type = "item-subgroup",
        name = "py-drilling",
        group = "coal-processing",
        order = "h"
    },
    {
        type = "item-subgroup",
        name = "py-mill",
        group = "coal-processing",
        order = "i"
    },
    {
        type = "item-subgroup",
        name = "py-filter",
        group = "coal-processing",
        order = "j"
    },
    {
        type = "item-subgroup",
        name = "py-sulfur",
        group = "coal-processing",
        order = "k"
    },
    {
        type = "item-subgroup",
        name = "py-extractor",
        group = "coal-processing",
        order = "l"
    },
    {
        type = "item-subgroup",
        name = "py-combustion",
        group = "coal-processing",
        order = "m"
    },
    {
        type = "item-subgroup",
        name = "py-fluids",
        group = "coal-processing",
        order = "z"
    },
    {
        type = "item-subgroup",
        name = "py-unsorted",
        group = "coal-processing",
        order = "zzzz"
    }
}

==> pycoalprocessing_1.9.3.zip: pycoalprocessing_1.9.3/prototypes/item-groups.lua <==
data:extend {
    {
        type = "item-group",
        name = "coal-processing",
        order = "t",
        inventory_order = "t",
        icon = "__pycoalprocessinggraphics__/graphics/technology/item-group.png",
        icon_size = 64
    },
--MKS--
    {
        type = "item-subgroup",
        name = "py-cp-buildings-mk01",
        group = "coal-processing",
        order = "a-a"
    },
    {
        type = "item-subgroup",
        name = "py-cp-buildings-mk02",
        group = "coal-processing",
        order = "a-b"
    },
    {
        type = "item-subgroup",
        name = "py-cp-buildings-mk03",
        group = "coal-processing",
        order = "a-c"
    },
    {
        type = "item-subgroup",
        name = "py-cp-buildings-mk04",
        group = "coal-processing",
        order = "a-d"
    },
    {
        type = "item-subgroup",
        name = "py-cp-buildings-others",
        group = "coal-processing",
        order = "a-e"
    },
----------------
    {
        type = "item-subgroup",
        name = "coal-processing",
        group = "coal-processing",
        order = "a1"
    },
    {
        type = "item-subgroup",
        name = "py-power",
        group = "coal-processing",
        order = "a2"
    },
    {
        type = "item-subgroup",
        name = "py-fluid-handling",
        group = "coal-processing",
        order = "a3"
    },
    {
        type = "item-subgroup",
        name = "py-extraction",
        group = "coal-processing",
        order = "a4"
    },
    {
        type = "item-subgroup",
        name = "py-items",
        group = "coal-processing",
        order = "c"
    },
    {
        type = "item-subgroup",
        name = "py-items-hpf",
        group = "coal-processing",
        order = "c-1"
    },
    {
        type = "item-subgroup",
        name = "py-items-class",
        group = "coal-processing",
        order = "c-2"
    },
    {
        type = "item-subgroup",
        name = "py-washer",
        group = "coal-processing",
        order = "c-3"
    },
    {
        type = "item-subgroup",
        name = "py-quenching-ores",
        group = "coal-processing",
        order = "d"
    },
    {
        type = "item-subgroup",
        name = "py-syngas",
        group = "coal-processing",
        order = "e"
    },
    {
        type = "item-subgroup",
        name = "py-methanol",
        group = "coal-processing",
        order = "f"
    },
    {
        type = "item-subgroup",
        name = "py-crusher",
        group = "coal-processing",
        order = "g"
    },
    {
        type = "item-subgroup",
        name = "py-drilling",
        group = "coal-processing",
        order = "h"
    },
    {
        type = "item-subgroup",
        name = "py-mill",
        group = "coal-processing",
        order = "i"
    },
    {
        type = "item-subgroup",
        name = "py-filter",
        group = "coal-processing",
        order = "j"
    },
    {
        type = "item-subgroup",
        name = "py-sulfur",
        group = "coal-processing",
        order = "k"
    },
    {
        type = "item-subgroup",
        name = "py-extractor",
        group = "coal-processing",
        order = "l"
    },
    {
        type = "item-subgroup",
        name = "py-combustion",
        group = "coal-processing",
        order = "m"
    },
    {
        type = "item-subgroup",
        name = "py-fluids",
        group = "coal-processing",
        order = "z"
    },
    {
        type = "item-subgroup",
        name = "py-unsorted",
        group = "coal-processing",
        order = "zzzz"
    }
}
